==> polls-v1.4.1.zip: polls/messages/th/base.php <==
<?php

return [
    '<strong>Note:</strong> The result is hidden until the poll is closed by a moderator.' => '<strong>หมายเหตุ:</strong> ผลลัพธ์จะถูกซ่อนไว้จนกว่าโพลล์จะปิดโดยผู้ดูแล',
    'Access denied!' => 'ปฏิเสธการเข้าใช้!',
    'Add answer...' => 'เพิ่มคำตอบ...',
    'Again? ;Weary;' => 'อีกแล้วเหรอ? ;เหน็ดเหนื่อย;',
    'Allows the user to create polls' => 'อนุญาตให้ผู้ใช้สร้างโพล',
    'Allows to start polls.' => 'อนุญาตให้เริ่มการเลือกตั้ง',
    'Anonymous' => 'ไม่ระบุชื่อ',
    'Anonymous Votes?' => 'โหวตแบบไม่ระบุชื่อ?',
    'Anonymous poll!' => 'โพลนิรนาม!',
    'Answers' => 'คำตอบ',
    'At least one answer is required' => 'จำเป็นต้องมีอย่างน้อยหนึ่งคำตอบ',
    'Cancel' => 'ยกเลิก',
    'Close Poll' => 'กรอกแบบสำรวจ',
    'Closed' => 'ปิด',
    'Club A Steakhouse' => 'คลับ เอ สเต็กเฮาส์',
    'Could not load poll!' => 'ไม่สามารถโหลดแบบสำรวจความคิดเห็น!',
    'Create poll' => 'สร้างโพล',
    'Description' => 'คำอธิบาย',
    'Display answers in random order?' => 'แสดงคำตอบแบบสุ่ม?',
    'Edit answer (empty answers will be removed)...' => 'แก้ไขคำตอบ (คำตอบที่ว่างเปล่าจะถูกลบออก)...',
    'Edit your poll question...' => 'แก้ไขคำถามแบบสำรวจของคุณ...',
    'Hide results until poll is closed?' => 'ซ่อนผลลัพธ์จนกว่าจะปิดโพล?',
    'Invalid answer!' => 'คำตอบที่ไม่ถูกต้อง!',
    'Location of the next meeting' => 'สถานที่ประชุมครั้งต่อไป',
    'Multiple answers per user' => 'หลายคำตอบต่อผู้ใช้',
    'Pisillo Italian Panini' => 'Pisillo อิตาลี Panini',
    'Please specify at least {min} answers!' => 'โปรดระบุอย่างน้อย {min} คำตอบ!',
    'Polls' => 'โพล',
    'Question' => 'คำถาม',
    'Reopen Poll' => 'เปิดโพลอีกครั้ง',
    'Reset my vote' => 'รีเซ็ตการโหวตของฉัน',
    'Right now, we are in the planning stages for our next meetup and we would like to know from you, where you would like to go?' => 'ตอนนี้เราอยู่ในขั้นตอนการวางแผนสำหรับการมีตติ้งครั้งต่อไป และเราอยากทราบจากคุณว่าคุณต้องการไปที่ไหน',
    'Save' => 'บันทึก',
    'To Daniel' => 'ถึงแดเนียล',
    'Users voted for: <strong>{answer}</strong>' => 'ผู้ใช้โหวตให้: <strong>{answer}</strong>',
    'Vote' => 'โหวต',
    'Voting for multiple answers is disabled!' => 'การลงคะแนนหลายคำตอบถูกปิดการใช้งาน!',
    'Whenever someone participates in a poll.' => 'เมื่อใดก็ตามที่มีคนมีส่วนร่วมในการสำรวจความคิดเห็น',
    'Why don\'t we go to Bemelmans Bar?' => 'ทำไมไม่ลองไปที่ Bemelmans Bar ล่ะ?',
    'You have insufficient permissions to perform that operation!' => 'คุณมีสิทธิ์ไม่เพียงพอที่จะดำเนินการดังกล่าว!',
    'and {count} more vote for this.' => 'และอีก {count} โหวตสำหรับสิ่งนี้',
    'votes' => 'โหวต',
    '{userName} answered the {question}.' => '{userName} ตอบคำถาม {question}',
    'Poll' => '',
    'Poll content ID' => '',
    '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}' => '',
];

==> polls-v1.4.2.zip: polls/messages/th/base.php <==
<?php

return [
    '<strong>Note:</strong> The result is hidden until the poll is closed by a moderator.' => '<strong>หมายเหตุ:</strong> ผลลัพธ์จะถูกซ่อนไว้จนกว่าโพลล์จะปิดโดยผู้ดูแล',
    'Access denied!' => 'ปฏิเสธการเข้าใช้!',
    'Add answer...' => 'เพิ่มคำตอบ...',
    'Again? :weary:' => 'อีกแล้วเหรอ? ;เหน็ดเหนื่อย;',
    'Allows the user to create polls' => 'อนุญาตให้ผู้ใช้สร้างโพล',
    'Allows to start polls.' => 'อนุญาตให้เริ่มการเลือกตั้ง',
    'Anonymous' => 'ไม่ระบุชื่อ',
    'Anonymous Votes?' => 'โหวตแบบไม่ระบุชื่อ?',
    'Anonymous poll!' => 'โพลนิรนาม!',
    'Answers' => 'คำตอบ',
    'At least one answer is required' => 'จำเป็นต้องมีอย่างน้อยหนึ่งคำตอบ',
    'Cancel' => 'ยกเลิก',
    'Close Poll' => 'กรอกแบบสำรวจ',
    'Closed' => 'ปิด',
    'Club A Steakhouse' => 'คลับ เอ สเต็กเฮาส์',
    'Could not load poll!' => 'ไม่สามารถโหลดแบบสำรวจความคิดเห็น!',
    'Create poll' => 'สร้างโพล',
    'Description' => 'คำอธิบาย',
    'Display answers in random order?' => 'แสดงคำตอบแบบสุ่ม?',
    'Edit answer (empty answers will be removed)...' => 'แก้ไขคำตอบ (คำตอบที่ว่างเปล่าจะถูกลบออก)...',
    'Edit your poll question...' => 'แก้ไขคำถามแบบสำรวจของคุณ...',
    'Hide results until poll is closed?' => 'ซ่อนผลลัพธ์จนกว่าจะปิดโพล?',
    'Invalid answer!' => 'คำตอบที่ไม่ถูกต้อง!',
    'Location of the next meeting' => 'สถานที่ประชุมครั้งต่อไป',
    'Multiple answers per user' => 'หลายคำตอบต่อผู้ใช้',
    'Pisillo Italian Panini' => 'Pisillo อิตาลี Panini',
    'Please specify at least {min} answers!' => 'โปรดระบุอย่างน้อย {min} คำตอบ!',
    'Polls' => 'โพล',
    'Question' => 'คำถาม',
    'Reopen Poll' => 'เปิดโพลอีกครั้ง',
    'Reset my vote' => 'รีเซ็ตการโหวตของฉัน',
    'Right now, we are in the planning stages for our next meetup and we would like to know from you, where you would like to go?' => 'ตอนนี้เราอยู่ในขั้นตอนการวางแผนสำหรับการมีตติ้งครั้งต่อไป และเราอยากทราบจากคุณว่าคุณต้องการไปที่ไหน',
    'Save' => 'บันทึก',
    'To Daniel' => 'ถึงแดเนียล',
    'Users voted for: <strong>{answer}</strong>' => 'ผู้ใช้โหวตให้: <strong>{answer}</strong>',
    'Vote' => 'โหวต',
    'Voting for multiple answers is disabled!' => 'การลงคะแนนหลายคำตอบถูกปิดการใช้งาน!',
    'Whenever someone participates in a poll.' => 'เมื่อใดก็ตามที่มีคนมีส่วนร่วมในการสำรวจความคิดเห็น',
    'Why don\'t we go to Bemelmans Bar?' => 'ทำไมไม่ลองไปที่ Bemelmans Bar ล่ะ?',
    'You have insufficient permissions to perform that operation!' => 'คุณมีสิทธิ์ไม่เพียงพอที่จะดำเนินการดังกล่าว!',
    'and {count} more vote for this.' => 'และอีก {count} โหวตสำหรับสิ่งนี้',
    'votes' => 'โหวต',
    '{userName} answered the {question}.' => '{userName} ตอบคำถาม {question}',
    'Poll' => '',
    'Poll content ID' => '',
    '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}' => '',
];
